pub enum ReplicaState {
Available,
Recovering,
Unavailable,
}Expand description
Operational state of a replica that may answer a query for a target range.
Variants
Available
Replica is available and not known to be recovering.
Recovering
Replica can answer, but its data may still be catching up.
Replica should not be selected for query execution.