pub struct ReplicaQuality {
pub start_time: u64,
pub end_time: u64,
pub points: u64,
pub expected_points: u64,
pub complete: bool,
pub state: ReplicaState,
}Expand description
Quality summary returned by a replica during replica resolution.
Fields
start_time: u64Earliest timestamp covered by the replica.
end_time: u64Latest timestamp covered by the replica.
points: u64Number of points observed in the covered interval.
expected_points: u64Expected points for a complete result in the covered interval.
complete: boolWhether the replica reports complete target coverage.
state: ReplicaStateCurrent operational state of the replica.
Implementations
Sourceimpl ReplicaQuality
impl ReplicaQuality
Sourcepub fn new(
start_time: u64,
end_time: u64,
points: u64,
expected_points: u64,
complete: bool,
state: ReplicaState,
) -> Self
pub fn new( start_time: u64, end_time: u64, points: u64, expected_points: u64, complete: bool, state: ReplicaState, ) -> Self
Creates a quality summary.
Sourcepub fn coverage_span(self) -> u64
pub fn coverage_span(self) -> u64
Returns the covered time span.
Sourcepub fn selectable(self) -> bool
pub fn selectable(self) -> bool
Returns true if this replica can be selected.