RangeAssigner

Struct RangeAssigner 

pub struct RangeAssigner<WorkerId> { /* private fields */ }
Assigns ordered key ranges to workers.

Implementations

Source

impl<WorkerId: Clone> RangeAssigner<WorkerId>

pub fn new() -> Self

Creates an empty range assigner.

pub fn assign( &mut self, range: Range<Vec<u8>>, worker: WorkerId, ) -> Result<(), ShardError>

Assigns range to worker.

pub fn try_assign( &mut self, range: Range<Vec<u8>>, worker: WorkerId, ) -> Result<(), ShardError>

Backwards-compatible alias for assign.

pub fn reassign_start( &mut self, start: &[u8], worker: WorkerId, ) -> Result<(), ShardError>

Reassigns the range that starts at start to worker.

pub fn split_at( &mut self, range_start: &[u8], split_key: Vec<u8>, right_worker: WorkerId, ) -> Result<(), ShardError>

Splits the range beginning at range_start at split_key.

pub fn worker_for<K: LexicographicKey + ?Sized>( &self, key: &K, ) -> Option<&WorkerId>

Looks up the worker for a typed lexicographic key.

pub fn worker_for_encoded(&self, encoded: &[u8]) -> Option<&WorkerId>

Looks up the worker for an already encoded key.

pub fn assignments( &self, ) -> impl Iterator<Item = (&Vec<u8>, &RangeAssignment<WorkerId>)>

Returns all range assignments keyed by inclusive start key.