pub struct RangeAssigner<WorkerId> { /* private fields */ }Expand description
Assigns ordered key ranges to workers.
Implementations
Sourceimpl<WorkerId: Clone> RangeAssigner<WorkerId>
impl<WorkerId: Clone> RangeAssigner<WorkerId>
Sourcepub fn assign(
&mut self,
range: Range<Vec<u8>>,
worker: WorkerId,
) -> Result<(), ShardError>
pub fn assign( &mut self, range: Range<Vec<u8>>, worker: WorkerId, ) -> Result<(), ShardError>
Assigns range to worker.
Sourcepub fn try_assign(
&mut self,
range: Range<Vec<u8>>,
worker: WorkerId,
) -> Result<(), ShardError>
pub fn try_assign( &mut self, range: Range<Vec<u8>>, worker: WorkerId, ) -> Result<(), ShardError>
Backwards-compatible alias for assign.
Sourcepub fn reassign_start(
&mut self,
start: &[u8],
worker: WorkerId,
) -> Result<(), ShardError>
pub fn reassign_start( &mut self, start: &[u8], worker: WorkerId, ) -> Result<(), ShardError>
Reassigns the range that starts at start to worker.
Sourcepub fn split_at(
&mut self,
range_start: &[u8],
split_key: Vec<u8>,
right_worker: WorkerId,
) -> Result<(), ShardError>
pub fn split_at( &mut self, range_start: &[u8], split_key: Vec<u8>, right_worker: WorkerId, ) -> Result<(), ShardError>
Splits the range beginning at range_start at split_key.
Sourcepub fn worker_for<K: LexicographicKey + ?Sized>(
&self,
key: &K,
) -> Option<&WorkerId>
pub fn worker_for<K: LexicographicKey + ?Sized>( &self, key: &K, ) -> Option<&WorkerId>
Looks up the worker for a typed lexicographic key.
Sourcepub fn worker_for_encoded(&self, encoded: &[u8]) -> Option<&WorkerId>
pub fn worker_for_encoded(&self, encoded: &[u8]) -> Option<&WorkerId>
Looks up the worker for an already encoded key.
Sourcepub fn assignments(
&self,
) -> impl Iterator<Item = (&Vec<u8>, &RangeAssignment<WorkerId>)>
pub fn assignments( &self, ) -> impl Iterator<Item = (&Vec<u8>, &RangeAssignment<WorkerId>)>
Returns all range assignments keyed by inclusive start key.